#R code for drawing Figure 2 & 3 in Hasegawa et al Scientific Data paper 
#Fig. 2. Data availability of crop yield simulations and its breakdown.
#Fig. 3. Distribution of climate change impacts on crop yields with and without adaptation
#Author: Hitomi Wakatsuki

rm(list=ls())
library(ggplot2)
library(dplyr)
library(openxlsx)
library(RColorBrewer)
library(rfUtilities)
library(moments)
library(ggpmisc)
library(plyr)
library(gcookbook)

#Datasheet
TAB<-read.xlsx("Projected_impacts_datasheet_11222021.xlsx", sheet=1)
head(TAB)

#Extraction of columns
Source<-as.factor(TAB$Methods)
Crop<-as.factor(TAB$"Crop")
Ref<-TAB$Ref.No
Region<-TAB$Region
Sample<-TAB$Sample.No.
ID=1:nrow(TAB)
Delta_temp_g<-as.numeric(TAB$`Global.delta.T.from.pre-industrial.period`)
Delta_temp_l<-as.numeric(TAB$Local.delta.T.from.2005)
Effect<-(TAB$Climate.impacts.relative.to.2005)
CO2.ppm<-TAB$CO2.ppm
TempAvg<-as.numeric(TAB$`Current.Average.Temperature.(dC)_area_weighted`)
Latitude<-TAB$latitude
Longitude<-TAB$longitude
Futureyear<-TAB$`Future_Mid-point`
Scenario <- TAB$Climate.scenario
Region<-factor(Region,levels = c("Africa","Asia","Australasia","Central and South America","Europe","North America","Global"))
Adaptation<-factor(TAB$Adaptation)
Fertiliser<-TAB$Fertiliser 
Irrigation<-TAB$Irrigation 
Cultivar<-TAB$Cultivar 
Soil_Organic<-TAB$Soil.organic.matter.management 
PlantingT<-TAB$Planting.time 
Tillage<-TAB$Tillage 
Others<-TAB$Others 
Timeslice <-TAB$Time.slice

DATA<- data.frame(Crop,Region,Delta_temp_g,Effect,Futureyear,Scenario,Adaptation)
DATA<- mutate(DATA,Climate_Scenario = ifelse(Scenario== "RCP2.6","RCP2.6",ifelse(Scenario =="RCP4.5","RCP4.5",ifelse(Scenario =="RCP6.0","RCP6.0",ifelse(Scenario == "RCP8.5","RCP8.5",ifelse(Scenario == "Others","Others","SRES"))))))
DATA$Climate_Scenario<-factor(DATA$Climate_Scenario,levels = c("RCP2.6","RCP4.5","RCP6.0","RCP8.5","SRES","Others"))


#Fig2_(a)
dev.new()
ggplot(data=DATA, aes(x=Delta_temp_g, y = (..count..)/sum(..count..), fill = Climate_Scenario)) + geom_histogram(binwidth = 0.5, color = "black", position="stack")+
  theme_bw()+ 
  theme(axis.text.x = element_text(size = 16)) +
  theme(axis.text.y = element_text(size = 16)) +
  theme(axis.title = element_text(size = 16))+
  scale_x_continuous(breaks=seq(0,5, by = 1))+
  scale_y_continuous(labels = scales::percent_format(accuracy = 1L))+
  scale_fill_brewer(palette = "Paired")+
  xlab("Global temeprature rise(\u00B0C)")+
  ylab("Relative frequency")+
    theme(axis.ticks.length = unit(-2, "mm"),
        axis.text.x = element_text(margin =unit(rep(8,4),"mm")),
        axis.text.y = element_text(margin =unit(rep(8,4),"mm"))) +
  theme(legend.text = element_text(size = 13)) 

ggsave(filename = "Figire2.a.tiff",dpi = 100, width = 6.5,height = 5)

#Fig2_(b)
dev.new(2)
ggplot(data= DATA, aes(x=Futureyear, y = (..count..)/sum(..count..),fill = Climate_Scenario)) + geom_histogram(binwidth = 10,color = "black", position="stack")+
  theme_bw()+ 
  theme(axis.text = element_text(size = 16))+
  theme(axis.title = element_text(size = 16)) +
  scale_fill_brewer(palette = "Paired")+
  scale_x_continuous(breaks=seq(2000,2100, by = 20))+
  scale_y_continuous(labels = scales::percent_format(accuracy = 1L))+
  xlab("Projected year")+
  ylab("Relative frequency")+
  theme(axis.ticks.length = unit(-2, "mm"),
        axis.text.x = element_text(margin =unit(rep(8,4),"mm")),
        axis.text.y = element_text(margin =unit(rep(8,4),"mm"))) +
  theme(legend.text = element_text(size = 13)) 

ggsave(filename = "Figire2.b.tiff",dpi = 100, width = 6.5,height = 5)


my.lables = c("Africa","Asia","Australasia","Central and \nSouth America","Europe","North America","Global")
#Fig2_(c)
dev.new(3)
ggplot(data= DATA, aes(x=Region, y = (..count..)/sum(..count..),fill = Crop)) + geom_bar(position="stack",color = "black")+
  theme_bw()+ 
  theme(axis.text.y = element_text(size = 14))+
  theme(axis.text.x = element_text(size = 14,angle = 90,vjust = 0.25, hjust = 1)) +
  theme(axis.title = element_text(size = 14)) +
  scale_fill_brewer(palette = "Paired")+
  scale_x_discrete(labels= my.lables)+
  scale_y_continuous(labels = scales::percent_format(accuracy = 1L))+
  xlab("Region")+
  ylab("Relative frequency")+
  theme(axis.ticks.length = unit(-2, "mm"),
        axis.text.x = element_text(margin =unit(rep(8,4),"mm")),
        axis.text.y = element_text(margin =unit(rep(8,4),"mm"))) +
  theme(legend.text = element_text(size = 13)) 

ggsave(filename = "Figire2.c.tiff",dpi = 100, width = 6.5,height = 6)

#Re-organizing datasheet to count "Adaptation options" 
DATA1<-data.frame(Crop,Effect,Scenario,Fertiliser,"Fertiliser")
DATA1 = filter(DATA1, Fertiliser == "Yes")
DATA2<-data.frame(Crop,Effect,Scenario,Cultivar,"Cultivar")
DATA2 = filter(DATA2, Cultivar == "Yes")
DATA3<-data.frame(Crop,Effect,Scenario,PlantingT,"Planting Time")
DATA3 = filter(DATA3, PlantingT == "Yes")
DATA4<-data.frame(Crop,Effect,Scenario,Tillage,"Tillage")
DATA4 = filter(DATA4, Tillage == "Yes")
DATA5<-data.frame(Crop,Effect,Scenario,Irrigation,"Irrigation")
DATA5 = filter(DATA5, Irrigation == "Yes")
DATA6<-data.frame(Crop,Effect,Scenario,Soil_Organic,"Soil Organic matter")
DATA6 = filter(DATA6, Soil_Organic == "Yes")
DATA7<-data.frame(Crop,Effect,Scenario,Others,"Others")
DATA7 = filter(DATA7, Others == "Yes")

names(DATA1)<-c("Crop","Effect","Scenario","Adaptation","Adaptation_options")
colnames(DATA2)<-colnames(DATA1)
colnames(DATA3)<-colnames(DATA1)
colnames(DATA4)<-colnames(DATA1)
colnames(DATA5)<-colnames(DATA1)
colnames(DATA6)<-colnames(DATA1)
colnames(DATA7)<-colnames(DATA1)
DATAU = rbind(DATA1,DATA2,DATA3,DATA4,DATA5,DATA6,DATA7)
DATAU$Adaptation_options <-factor(DATAU$Adaptation_options, levels = c("Cultivar","Fertiliser","Planting Time","Tillage","Irrigation","Soil Organic matter","Others"))
summary(DATAU$Adaptation_options)

adaptation.lables = c("Cultivar","Fertiliser","Planting date","Tillage","Irrigation","Soil organic matter\nmanagement","Others")

#Fig2_(d)
dev.new(4)
ggplot(DATAU,aes(x =Adaptation_options , y = (..count..)/sum(..count..), fill = Crop))+
  geom_bar(position = "stack", color = "black")+
  theme_bw()+
  theme(axis.title = element_text(size=16))+
  theme(axis.text.x = element_text(size = 16,angle = 90, vjust = 0.25, hjust =1 )) +
  theme(axis.text.y = element_text(size = 16))+
  scale_x_discrete(labels= adaptation.lables)+
  scale_fill_brewer(palette = "Paired")+
  scale_y_continuous(labels = scales::percent_format(accuracy = 1L))+
  ylab("Relative frequncy ")+
  xlab("Adaptation options")+
  theme(axis.ticks.length = unit(-2, "mm"),
        axis.text.x = element_text(margin =unit(rep(8,4),"mm")),
        axis.text.y = element_text(margin =unit(rep(8,4),"mm"))) +
  theme(legend.text = element_text(size = 13)) 

ggsave(filename = "Figire2.d.tiff",dpi = 100, width = 6.5,height = 6.2)

#Fig.3 
#Selecting with and without adaptation
##########################
DATA = filter(DATA, CO2 =="Yes")
Effect_Adap = filter(DATA, Adaptation == "Yes")
Effect_Adap<- Effect_Adap$Effect
Effect_noAdap = filter(DATA, Adaptation == "No")
Effect_noAdap<- Effect_noAdap$Effect
#######################
#Summary descriptive statistics
#######################
summary(Effect_Adap)
summary(Effect_noAdap)

skewness(Effect_Adap)
skewness(Effect_noAdap)
kurtosis(Effect_Adap)
kurtosis(Effect_noAdap)

min = min(Effect_Adap)
max = max(Effect_Adap) 
mean = mean(Effect_Adap)
q1= quantile(Effect_Adap, probs = 0.25)
median = median(Effect_Adap)
q3= quantile(Effect_Adap, probs = 0.75)
sd = sd(Effect_Adap)
skewness=skewness(Effect_Adap)
kurtosis=kurtosis(Effect_Adap)
With_Adapt=round(c(min, max, mean, q1, median, q3, sd, skewness, kurtosis), digits=1)
min = min(Effect_noAdap)
max = max(Effect_noAdap) 
mean = mean(Effect_noAdap)
q1= quantile(Effect_noAdap, probs = 0.25)
median = median(Effect_noAdap)
q3= quantile(Effect_noAdap, probs = 0.75)
sd = sd(Effect_noAdap)
skewness=skewness(Effect_noAdap)
kurtosis=kurtosis(Effect_noAdap)
Without_Adapt=round(c(min, max, mean, q1, median, q3, sd, skewness, kurtosis), digits=1)

variables<-c("Min", "Max", "mean", "q1", "median", "q3", "sd", "skewness", "kurtosis")

summ<-data.frame(variables,With_Adapt,Without_Adapt)
summ

## Fig3 
dev.new(5)
ggplot(DATA, aes(x=Effect, num = nrow(DATA), y=(..count..)/num*100,fill = Adaptation))+
  geom_histogram(alpha=0.5,colour = "darkgrey")+
  geom_table_npc(data=summ,label=list(summ), npcx = 0.5, npcy =1, hjust = 0, vjust =1,size=4.5)+
  theme_classic()+
  xlab("Yield change (%)")+
  ylab("Relative frequency (%)")+
  theme(axis.text.x = element_text(color = "grey20", size = 15, angle = 0, hjust = .5, vjust = .5, face = "plain"),
        axis.text.y = element_text(color = "grey20", size = 15, angle = 0, hjust = 0.5, vjust = 0.5, face = "plain"),  
        axis.title.x = element_text(color = "grey20", size = 18, angle = 0, hjust = .5, vjust = 0, face = "plain"),
        axis.title.y = element_text(color = "grey20", size = 18, angle = 90, hjust =0.5, vjust =1, face = "plain"),
        legend.text = element_text(color = "grey20", size=15),
        legend.title = element_text(color="grey20", size=15),
        legend.position=c(0.2,0.5))+
  scale_y_continuous(limits=c(0,40))+
  scale_x_continuous(breaks=seq(-150,100, by = 50))+
  theme(axis.ticks.length = unit(-2, "mm"),
        axis.text.x = element_text(margin =unit(rep(8,4),"mm")),
        axis.text.y = element_text(margin =unit(rep(8,4),"mm"))) +
  theme(legend.text = element_text(size = 13)) +
  scale_fill_viridis_d()

ggsave("Figure.3.tiff",dpi = 100, width = 8,height = 7)
