#R code for drawing Figure 5 in Hasegawa et al Scientific Data paper 
#Fig. 5  Projected yield changes relative to the baseline period (2001-2010). 
#Author: Hitomi Wakatsuki

rm(list=ls())
library(ggplot2)
library(dplyr)
library(openxlsx)
library(EnvStats)
library(RColorBrewer)
library(tidyverse)
library(svglite)

TAB<-read.xlsx("Projected_impacts_datasheet_11242021.xlsx", sheet=1)

#Extraction of columns
Species<-as.factor(TAB$"Crop")
Ref<-TAB$Ref.No
Scale<-TAB$Scale
Country<-TAB$Country
ID=1:nrow(TAB)
Delta_temp_g<-as.numeric(TAB$`Global.delta.T.from.pre-industrial.period`)
Delta_temp_l<-as.numeric(TAB$Local.delta.T.from.2005)
Effect<-(TAB$Climate.impacts.relative.to.2005)
CO2.ppm<-TAB$CO2.ppm
CO2<-TAB$CO2
RCP<-as.factor(TAB$Climate.scenario)
TempAvg<-as.numeric(TAB$`Current.Average.Temperature.(dC)_area_weighted`)
Anunal_pr<-as.numeric(TAB$`Current.Annual.Precipitation.(mm)._area_weighted`)
Latitude<-TAB$latitude
Longitude<-TAB$longitude
Futureyear<-TAB$`Future_Mid-point`
Region = factor(TAB$Region,levels = c(levels = c("Africa","Asia","Australasia","Central and South America","Europe","North America","Global")))
Timeslice = factor(TAB$Time.slice, levels = c("NF","MC","EC"))
Adaptation =factor(TAB$Adaptation,levels = c("No","Yes"),labels = c("Without_adapt","With_adapt"))

DATA<- data.frame(Species,Ref,Scale,Region,Country,Effect,RCP,TempAvg,Latitude,Longitude,Timeslice,Delta_temp_g,Adaptation,CO2)
##Selecting CO2 effect = "Yes" 
DATA = filter(DATA, Region != "Global" & CO2 =="Yes")

#adding categories for Temperature ranges 
DATA = DATA%>%mutate(bin = ifelse(Delta_temp_g <= 1.5, "\u2264 1.5",ifelse(Delta_temp_g >1.5 & Delta_temp_g <=2.5,"\u2264 2.5",ifelse(Delta_temp_g >2.5 & Delta_temp_g <=3.5,"\u2264 3.5","3.5<"))))
bin = factor(DATA$bin, levels = c("\u2266 1.5","\u2266 2.5","\u2266 3.5","3.5<"))
DATA = DATA%>%mutate(Tavebin = cut_width(TempAvg,width = 5,labels = c(-5,0,5,10,15,20,25,30)))
DATA = DATA%>%mutate(Tavebin2 = ifelse(Tavebin =="0" | Tavebin == "-5","0",ifelse(Tavebin == "5","5",ifelse(Tavebin == "10","10", ifelse(Tavebin=="15","15",ifelse(Tavebin=="20","20",ifelse(Tavebin=="25","25","30")))))))
DATA$Tavebin2 = factor(DATA$Tavebin2,levels = c("0","5","10","15","20","25","30"))
DATA = DATA%>%mutate(Tave = ifelse(TempAvg < 10, "<10",ifelse((TempAvg >=10 & TempAvg <20),"10<20","20<")))
Tave = factor(DATA$Tave, levels = c("<10","10<20","20<"))


#Selecting RCP & Adaptation & Timeslice 
RCP_DATA = filter(DATA, RCP == "RCP2.6"|RCP == "RCP4.5"|RCP == "RCP8.5")

RCP_DATA_NA = filter(RCP_DATA, Adaptation == "Without_adapt")
RCP_DATA_NA_EC = filter(RCP_DATA_NA, Timeslice == "EC")
RCP_DATA_NA_MCEC = filter(RCP_DATA_NA, Timeslice != "NF")

RCP_DATA_MC = filter(RCP_DATA, Timeslice=="MC")
RCP_DATA_EC = filter(RCP_DATA, Timeslice == "EC")
my.lables = c("Africa","Asia","Australasia","Central and \nSouth America","Europe","North America")


# Fig5_(a)
dev.new(1)
ggplot(RCP_DATA_MC, aes(x =Tavebin2, y = Effect, fill=RCP))+
  geom_boxplot(outlier.alpha = 0.1)+
  theme_bw()+
  stat_n_text(y.pos=60, size = 3.2)+
  geom_abline(intercept = 0, slope = 0, color = "blue")+
  ggtitle("Mid-Century")+
  scale_fill_manual(values = c("#A6CEE3","#33A02C","#FB9A99"))+
  xlab("Current average temperature (\u00B0C) ") +
  ylab("Yield change(%)")+
  theme(axis.line = element_line(color = "black", size = 1, linetype = "solid"))+
  theme(axis.text = element_text(size = 14))+
  theme(axis.title = element_text(size = 14))+
  coord_cartesian(ylim = c(-100,75))+
  scale_y_continuous(breaks=seq(-100,50,by = 25)) +
  theme(axis.ticks.length = unit(-2, "mm"),
        axis.text.x = element_text(margin =unit(rep(8,4),"mm")),
        axis.text.y = element_text(margin =unit(rep(8,4),"mm"))) +
  theme(legend.text = element_text(size = 13)) +
  facet_grid(Adaptation ~ Species) +
  theme(strip.text.y = element_text(size=14,face="bold"),
        strip.text.x = element_text(size = 14, face ="bold")) 
ggsave(filename = "Figire5_(a).tiff",dpi = 100, width = 13, height = 5)

# Fig5_(b)
dev.new(2)
ggplot(RCP_DATA_EC, aes(x =Tavebin2, y = Effect, fill=RCP))+
  geom_boxplot(outlier.alpha = 0.1)+
  theme_bw()+
  stat_n_text(y.pos=60, size = 3.2)+
  geom_abline(intercept = 0, slope = 0, color = "blue")+
  ggtitle("End-Century")+
  scale_fill_manual(values = c("#A6CEE3","#33A02C","#FB9A99"))+
  xlab("Current average temperature (\u00B0C) ") +
  ylab("Yield change(%)")+
  theme(axis.line = element_line(color = "black", size = 1, linetype = "solid"))+
  theme(axis.text = element_text(size = 14))+
  theme(axis.title = element_text(size = 14))+
  coord_cartesian(ylim = c(-100,75))+
  scale_y_continuous(breaks=seq(-100,50,by = 25)) +
  theme(axis.ticks.length = unit(-2, "mm"),
        axis.text.x = element_text(margin =unit(rep(8,4),"mm")),
        axis.text.y = element_text(margin =unit(rep(8,4),"mm"))) +
  theme(legend.text = element_text(size = 13)) +
  facet_grid(Adaptation ~ Species) +
  theme(strip.text.y = element_text(size=14,face="bold"),
        strip.text.x = element_text(size = 14, face ="bold"))
ggsave(filename = "Figire5_(b).tiff",dpi = 100, width = 13, height = 5)

## Fig5_(c) 
dev.new(3)
ggplot(RCP_DATA, aes(x = bin, y = Effect, fill= Tave))+
  geom_boxplot(outlier.alpha=0.1)+
  theme_bw()+
  theme(axis.text= element_text(size = 14))+
  scale_fill_manual(values = c("#B2DF8A","#FFFF99","#E31A1C"))+
  geom_abline(intercept = 0, slope = 0, color = "blue")+
  xlab("Temperature rise(\u00B0C)") +
  ylab("Yield change (%)")+
  theme(axis.line = element_line(color = "black", size = 1, linetype = "solid"))+
  theme(axis.title = element_text(size = 14))+
  coord_cartesian(ylim = c(-100,75))+
  scale_y_continuous(breaks=seq(-100,50, by =25)) +
   theme(axis.ticks.length = unit(-2, "mm"),
        axis.text.x = element_text(margin =unit(rep(8,4),"mm")),
        axis.text.y = element_text(margin =unit(rep(8,4),"mm"))) +
  theme(legend.text = element_text(size = 13)) +
  facet_grid(Adaptation~Species) +
  stat_n_text(size = 3.2, y.pos = 60)+
  theme(strip.text.y = element_text(size=14,face="bold"),
        strip.text.x = element_text(size = 14, face ="bold"))  
ggsave(filename = "Figire5_(c).tiff",dpi = 100, width = 13, height = 5)
