#R code for estimating missing delta temperatures and precipitations for climate change impacts studies
# used in Hasegawa et al Scientific Data paper 
#Author: Hitomi Wakatsuki & David Makowski

###Computlibrary(openxlsx)
rm(list=ls())
library(randomForest)
library(pdp)
library(lme4)
library(rfUtilities)
library(openxlsx)
library(dplyr)



#Data import

TAB<-read.xlsx("Projected_impacts_datasheet_11.24.2021.xlsx", sheet=1)


TAB = TAB%>%mutate(LocalT_original = ifelse(TAB$Local.delta.T =="NA","NA",TAB$Local.delta.T.from.2005))
TAB = TAB%>%mutate(GlobalT_original = ifelse(is.na(TAB$`Note4.(*.=.Global.temperature.is.estimated.)`),TAB$Global.delta.T.from.2005,"NA"))


#Extraction of columns

Species<-as.factor(TAB$"Crop")
Ref<-TAB$Ref.No
ID=1:nrow(TAB)
Delta_temp_g<-as.numeric(TAB$GlobalT_original)
Delta_temp_l<-as.numeric(TAB$LocalT_original)
Pr_change<-as.numeric(TAB$`Annual.Precipitation.change.from.2005.(mm)`)
Pr_avg<-as.numeric(TAB$`Current.Annual.Precipitation.(mm)._area_weighted`)
Effect<-as.numeric(TAB$Climate.impacts.relative.to.2005)
CO2.ppm<-TAB$CO2.ppm
RCP<-as.factor(TAB$Climate.scenario)
TempAvg<-as.numeric(TAB$`Current.Average.Temperature.(dC)_area_weighted`)
Latitude<-TAB$latitude
Longitude<-TAB$longitude
Futureyear<-TAB$`Future_Mid-point`



#######################
#Method: random forest#
#######################
##Local Temperature delta Prediction
# Cross validation 

DATA<-data.frame(Delta_temp_l,Delta_temp_g,Latitude, Longitude)
DATA2<-data.frame(Delta_temp_l,Delta_temp_g, RCP, Futureyear)
DATA3<-data.frame(Delta_temp_l,Delta_temp_g, Longitude, Latitude, RCP,Futureyear)
DATA4<-data.frame(Delta_temp_l,Delta_temp_g, Longitude, Latitude,TempAvg)


DATA_train<-na.omit(DATA)
DATA_train2<-na.omit(DATA2)
DATA_train3<-na.omit(DATA3)
DATA_train4<-na.omit(DATA4)


mod.rf <- randomForest(Delta_temp_l~., importance=T, data=DATA_train, ntree=500)
mod.rf

mod.rf2 <- randomForest(Delta_temp_l~., importance=T, data=DATA_train2, ntree=500)
mod.rf2

mod.rf3 <- randomForest(Delta_temp_l~., importance=T, data=DATA_train3, ntree=500)
mod.rf3

mod.rf4 <- randomForest(Delta_temp_l~., importance=T, data=DATA_train4, ntree=500)
mod.rf4


rf.crossValidation(mod.rf,DATA_train[,2:4], p= 0.10,n= 99, ntree =500)
rf.crossValidation(mod.rf2,DATA_train2[,2:4], p= 0.10,n= 99, ntree =500)
rf.crossValidation(mod.rf3,DATA_train3[,2:6], p= 0.10,n= 99, ntree =500)
rf.crossValidation(mod.rf4,DATA_train4[,2:5], p= 0.10,n= 99, ntree =500)

importance(mod.rf, type=1, scale=F)
importance(mod.rf2, type=1, scale=F)
importance(mod.rf3, type=1, scale=F)
importance(mod.rf4, type=1, scale=F)


# ploting Fit 
dev.new()
par(mfrow=c(1,2))
plot(predict(mod.rf),DATA_train$Delta_temp_l, xlab=expression("Fitted ("*~degree*C*")"), ylab="Observed(\u00B0C)")
abline(0,1)
plot(predict(mod.rf),(DATA_train$Delta_temp_l-predict(mod.rf)), xlab="Fitted (\u00B0C)", ylab="Residuals")
abline(0,0)

#Importance
dev.new()
varImpPlot(mod.rf, type=1, scale=F)

dev.new()
partial(mod.rf, pred.var=c("Delta_temp_g"), plot=T, rug=T)

#Predictions
DATA_predict<-DATA[is.na(DATA$Delta_temp_g)==F & is.na(DATA$Latitude)==F & is.na(DATA$Longitude)==F & is.na(DATA$Delta_temp_l)==T,]
ID_predict<-ID[is.na(DATA$Delta_temp_g)==F & is.na(DATA$Latitude)==F & is.na(DATA$Longitude)==F & is.na(DATA$Delta_temp_l)==T]
Delta_temp_l_pred<-predict(mod.rf, newdata=DATA_predict)


dev.new()
plot(DATA_predict$Delta_temp_g, Delta_temp_l_pred,xlab="Global temperature change(\u00B0C)", ylab="Predicted local temperature change(\u00B0C)")

Result_RF_temp<-data.frame(ID_predict,Delta_temp_l_pred,DATA_predict)
write.csv(Result_RF_temp, "Predicted_local_temp_change_RF.csv")


##### Global temperature delta prediction 

DATA<-data.frame(Delta_temp_g,Delta_temp_l,Latitude, Longitude)
DATA2<-data.frame(Delta_temp_g,Delta_temp_l, RCP, Futureyear)
DATA3<-data.frame(Delta_temp_g,Delta_temp_l, Longitude, Latitude, RCP,Futureyear)
DATA4<-data.frame(Delta_temp_g,Delta_temp_l,Latitude, Longitude,TempAvg)


DATA_train<-na.omit(DATA)
DATA_train2<-na.omit(DATA2)
DATA_train3<-na.omit(DATA3)
DATA_train4<-na.omit(DATA4)



mod.rf <- randomForest(Delta_temp_g~., importance=T, data=DATA_train, ntree=500)
mod.rf

mod.rf2 <- randomForest(Delta_temp_g~., importance=T, data=DATA_train2, ntree=500)
mod.rf2

mod.rf3 <- randomForest(Delta_temp_g~., importance=T, data=DATA_train3, ntree=500)
mod.rf3

mod.rf4 <- randomForest(Delta_temp_g~., importance=T, data=DATA_train4, ntree=500)
mod.rf4

rf.crossValidation(mod.rf,DATA_train[,2:4], p= 0.10,n= 99, ntree =500)
rf.crossValidation(mod.rf2,DATA_train2[,2:4], p= 0.10,n= 99, ntree =500)
rf.crossValidation(mod.rf3,DATA_train3[,2:6], p= 0.10,n= 99, ntree =500)
rf.crossValidation(mod.rf4,DATA_train4[,2:5], p= 0.10,n= 99, ntree =500)

importance(mod.rf, type=1, scale=F)
importance(mod.rf2, type=1, scale=F)
importance(mod.rf3, type=1, scale=F)
importance(mod.rf4, type=1, scale=F)


# ploting Fit 
dev.new()
par(mfrow=c(1,2))
plot(predict(mod.rf3),DATA_train3$Delta_temp_g, xlab=expression("Fitted ("*~degree*C*")"), ylab="Observed(\u00B0C)")
abline(0,1)
plot(predict(mod.rf3),(DATA_train3$Delta_temp_g-predict(mod.rf3)), xlab="Fitted (\u00B0C)", ylab="Residuals")
abline(0,0)

#Importance
dev.new()
varImpPlot(mod.rf3, type=1, scale=F)

dev.new()
partial(mod.rf3, pred.var=c("Delta_temp_l"), plot=T, rug=T)

#Predictions
DATA_predict<-DATA3[is.na(DATA3$Delta_temp_l)==F & is.na(DATA3$Latitude)==F & is.na(DATA3$Longitude)==F & is.na(DATA3$Delta_temp_g)==T, ]
ID_predict<-ID[is.na(DATA3$Delta_temp_l)==F & is.na(DATA3$Latitude)==F & is.na(DATA3$Longitude)==F & is.na(DATA3$Delta_temp_g)==T ]
Delta_temp_g_pred<-predict(mod.rf3, newdata=DATA_predict)

dev.new()
plot(DATA_predict$Delta_temp_l, Delta_temp_g_pred,xlab="Local temperature change(\u00B0C)", ylab="Predicted Global temperature change(\u00B0C)")

Result_RF_temp<-data.frame(ID_predict,Delta_temp_g_pred,DATA_predict)
write.csv(Result_RF_temp, "Predicted_global_temp_change_RF.csv")

########## Precipitation change prediction ###### 

TAB = TAB%>%mutate(Pr_original = ifelse(is.na(TAB$`Note3.(*.=.Local.delta.Pr.is.estimated.)`),TAB$`Annual.Precipitation.change.from.2005.(mm)`,"NA"))

head(TAB)
#Extraction of columns

Species<-as.factor(TAB$"Crop")
Ref<-TAB$Ref.No
ID=1:nrow(TAB)
Delta_temp_g<-as.numeric(TAB$Global.delta.T.from.2005)
Delta_temp_l<-as.numeric(TAB$Local.delta.T.from.2005)
Pr_change<-as.numeric(TAB$Pr_original)
Pr_avg<-as.numeric(TAB$`Current.Annual.Precipitation.(mm)._area_weighted`)
Effect<-as.numeric(TAB$Climate.impacts.relative.to.2005)
CO2.ppm<-TAB$CO2.ppm
RCP<-as.factor(TAB$Climate.scenario)
TempAvg<-as.numeric(TAB$`Current.Average.Temperature.(dC)_area_weighted`)
Latitude<-TAB$latitude
Longitude<-TAB$longitude
Futureyear<-TAB$`Future_Mid-point`




DATA<-data.frame(Pr_change,Delta_temp_l,Delta_temp_g,Latitude, Longitude)
DATA2<-data.frame(Pr_change,Delta_temp_l,Delta_temp_g, RCP, Futureyear)
DATA3<-data.frame(Pr_change,Delta_temp_l,Delta_temp_g,Pr_avg)
DATA4<-data.frame(Pr_change,Delta_temp_l,Delta_temp_g, Longitude, Latitude, RCP,Futureyear,Pr_avg)
DATA5<-data.frame(Pr_change,Delta_temp_l,Delta_temp_g, Longitude, Latitude,RCP)
DATA6<-data.frame(Pr_change,Delta_temp_l, Longitude, Latitude, RCP, Futureyear, Pr_avg)
DATA7<-data.frame(Pr_change,Delta_temp_l,Delta_temp_g, Longitude, Latitude,TempAvg)
DATA8<-data.frame(Pr_change,Delta_temp_l,Delta_temp_g, Longitude, Latitude, RCP, Futureyear, TempAvg,Pr_avg,Species,Effect)


DATA_train<-na.omit(DATA)
DATA_train2<-na.omit(DATA2)
DATA_train3<-na.omit(DATA3)
DATA_train4<-na.omit(DATA4)
DATA_train5<-na.omit(DATA5)
DATA_train6<-na.omit(DATA6)
DATA_train7<-na.omit(DATA7)
DATA_train8<-na.omit(DATA8)

mod.rf <- randomForest(Pr_change~., importance=T, data=DATA_train, ntree=500)
mod.rf
mod.rf2 <- randomForest(Pr_change~., importance=T, data=DATA_train2, ntree=500)
mod.rf2
mod.rf3 <- randomForest(Pr_change~., importance=T, data=DATA_train3, ntree=500)
mod.rf3
mod.rf4 <- randomForest(Pr_change~., importance=T, data=DATA_train4, ntree=500)
mod.rf4
mod.rf5 <- randomForest(Pr_change~., importance=T, data=DATA_train5, ntree=500)
mod.rf5
mod.rf6 <- randomForest(Pr_change~., importance=T, data=DATA_train6, ntree=500)
mod.rf6
mod.rf7 <- randomForest(Pr_change~., importance=T, data=DATA_train7, ntree=500)
mod.rf7
mod.rf8 <- randomForest(Pr_change~., importance=T, data=DATA_train8, ntree=500)
mod.rf8

rf.crossValidation(mod.rf,DATA_train[,2:5], p= 0.10,n= 99, ntree =500)
rf.crossValidation(mod.rf2,DATA_train2[,2:5], p= 0.10,n= 99, ntree =500)
rf.crossValidation(mod.rf3,DATA_train3[,2:4], p= 0.10,n= 99, ntree =500)
rf.crossValidation(mod.rf4,DATA_train4[,2:8], p= 0.10,n= 99, ntree =500)
rf.crossValidation(mod.rf5,DATA_train5[,2:6], p= 0.10,n= 99, ntree =500)
rf.crossValidation(mod.rf6,DATA_train6[,2:7], p= 0.10,n= 99, ntree =500)
rf.crossValidation(mod.rf7,DATA_train7[,2:6], p= 0.10,n= 99, ntree =500)
rf.crossValidation(mod.rf8,DATA_train8[,2:11], p= 0.10,n= 99, ntree =500)



importance(mod.rf, type=1, scale=F)
importance(mod.rf2, type=1, scale=F)
importance(mod.rf3, type=1, scale=F)
importance(mod.rf4, type=1, scale=F)
importance(mod.rf5, type=1, scale=F)
importance(mod.rf6, type=1, scale=F)
importance(mod.rf7, type=1, scale=F)
importance(mod.rf8, type=1, scale=F)

#Predictions
DATA_predict<-DATA4[is.na(DATA4$Latitude)==F & is.na(DATA4$Longitude)==F & is.na(DATA4$Pr_change)==T, ]
ID_predict<-ID[is.na(DATA4$Latitude)==F & is.na(DATA4$Longitude)==F & is.na(DATA4$Pr_change)==T ]
Delta_pr_pred<-predict(mod.rf4, newdata=DATA_predict)


Result_RF_temp<-data.frame(ID_predict,Delta_pr_pred,DATA_predict)
write.csv(Result_RF_temp, "Predicted_Pr_change_RF.csv")
